==> react-molecule-autosuggest-2.57.0.tgz: package/lib/components/SingleSelection/index.js <==
/* eslint-disable react/prop-types */
import { Children } from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import AtomInput from '@s-ui/react-atom-input';
import { InputWithClearUI } from '../InputWithClearUI/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeAutosuggestSingleSelection = function MoleculeAutosuggestSingleSelection(_ref) {
  var autoClose = _ref.autoClose,
      autoFocus = _ref.autoFocus,
      ariaLabel = _ref.ariaLabel,
      _ref$autoComplete = _ref.autoComplete,
      autoComplete = _ref$autoComplete === void 0 ? 'nope' : _ref$autoComplete,
      children = _ref.children,
      design = _ref.design,
      disabled = _ref.disabled,
      iconClear = _ref.iconClear,
      id = _ref.id,
      _ref$innerRefInput = _ref.innerRefInput,
      refInput = _ref$innerRefInput === void 0 ? {} : _ref$innerRefInput,
      inputMode = _ref.inputMode,
      isOpen = _ref.isOpen,
      leftIcon = _ref.leftIcon,
      maxLength = _ref.maxLength,
      minLength = _ref.minLength,
      onChange = _ref.onChange,
      onClear = _ref.onClear,
      onClickRightIcon = _ref.onClickRightIcon,
      onInputKeyDown = _ref.onInputKeyDown,
      onKeyDown = _ref.onKeyDown,
      onSelect = _ref.onSelect,
      onToggle = _ref.onToggle,
      placeholder = _ref.placeholder,
      required = _ref.required,
      rightButton = _ref.rightButton,
      rightIcon = _ref.rightIcon,
      shape = _ref.shape,
      size = _ref.size,
      tabIndex = _ref.tabIndex,
      type = _ref.type,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value;

  var handleSelection = function handleSelection(ev, _ref2) {
    var value = _ref2.value;
    typeof onChange === 'function' && onChange(ev, {
      value: value
    });
    typeof onSelect === 'function' && onSelect(ev, {
      value: value
    });
    autoClose && typeof onToggle === 'function' && onToggle(ev, {
      isOpen: false
    });
  };

  var handleChange = function handleChange(ev, _ref3) {
    var value = _ref3.value;
    typeof onChange === 'function' && onChange(ev, {
      value: value
    });
    autoClose && typeof onToggle === 'function' && onToggle(ev, {
      isOpen: true
    });
  };

  var handleClear = function handleClear(ev) {
    if (!disabled) {
      typeof onChange === 'function' && onChange(null, {
        value: ''
      });
      typeof onClear === 'function' && onClear(ev);
    }
  };

  var handleRightClick = function handleRightClick(ev) {
    typeof onClickRightIcon === 'function' && onClickRightIcon(ev, {
      value: value
    });
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(InputWithClearUI, {
      ariaLabel: ariaLabel,
      autoComplete: autoComplete,
      autoFocus: autoFocus,
      button: rightButton,
      disabled: disabled,
      iconClear: !disabled && iconClear,
      id: id,
      reference: refInput,
      inputMode: inputMode,
      isVisibleClear: value,
      leftIcon: leftIcon,
      maxLength: maxLength,
      minLength: minLength,
      onChange: handleChange,
      onClickClear: handleClear,
      onClickRightIcon: handleRightClick,
      onKeyDown: onInputKeyDown,
      placeholder: placeholder,
      required: required,
      rightIcon: rightIcon,
      shape: shape,
      tabIndex: tabIndex,
      type: type,
      value: value,
      children: /*#__PURE__*/_jsx(AtomInput, {})
    }), value && /*#__PURE__*/_jsx(MoleculeDropdownList, {
      size: size,
      visible: isOpen && Children.count(children) > 0,
      onSelect: handleSelection,
      value: value,
      highlightQuery: value,
      onKeyDown: onKeyDown,
      design: design,
      children: children
    })]
  });
};

MoleculeAutosuggestSingleSelection.displayName = 'MoleculeAutosuggestSingleSelection';
export default MoleculeAutosuggestSingleSelection;

==> react-molecule-autosuggest-2.59.0.tgz: package/lib/components/SingleSelection/index.js <==
/* eslint-disable react/prop-types */
import { Children } from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import AtomInput from '@s-ui/react-atom-input';
import { InputWithClearUI } from '../InputWithClearUI/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeAutosuggestSingleSelection = function MoleculeAutosuggestSingleSelection(_ref) {
  var autoFocus = _ref.autoFocus,
      ariaLabel = _ref.ariaLabel,
      _ref$autoComplete = _ref.autoComplete,
      autoComplete = _ref$autoComplete === void 0 ? 'nope' : _ref$autoComplete,
      children = _ref.children,
      design = _ref.design,
      disabled = _ref.disabled,
      iconClear = _ref.iconClear,
      id = _ref.id,
      _ref$innerRefInput = _ref.innerRefInput,
      refInput = _ref$innerRefInput === void 0 ? {} : _ref$innerRefInput,
      inputMode = _ref.inputMode,
      isOpen = _ref.isOpen,
      leftIcon = _ref.leftIcon,
      maxLength = _ref.maxLength,
      minLength = _ref.minLength,
      onChange = _ref.onChange,
      onClear = _ref.onClear,
      onClickRightIcon = _ref.onClickRightIcon,
      onInputKeyDown = _ref.onInputKeyDown,
      onKeyDown = _ref.onKeyDown,
      onSelect = _ref.onSelect,
      onToggle = _ref.onToggle,
      placeholder = _ref.placeholder,
      required = _ref.required,
      rightButton = _ref.rightButton,
      rightIcon = _ref.rightIcon,
      shape = _ref.shape,
      size = _ref.size,
      tabIndex = _ref.tabIndex,
      type = _ref.type,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value;

  var handleSelection = function handleSelection(ev, _ref2) {
    var value = _ref2.value;
    typeof onChange === 'function' && onChange(ev, {
      value: value
    });
    typeof onSelect === 'function' && onSelect(ev, {
      value: value
    });
    typeof onToggle === 'function' && onToggle(ev, {
      isOpen: false
    });
  };

  var handleChange = function handleChange(ev, _ref3) {
    var value = _ref3.value;
    typeof onChange === 'function' && onChange(ev, {
      value: value
    });
    typeof onToggle === 'function' && onToggle(ev, {
      isOpen: true
    });
  };

  var handleClear = function handleClear(ev) {
    if (!disabled) {
      typeof onChange === 'function' && onChange(null, {
        value: ''
      });
      typeof onClear === 'function' && onClear(ev);
    }
  };

  var handleRightClick = function handleRightClick(ev) {
    typeof onClickRightIcon === 'function' && onClickRightIcon(ev, {
      value: value
    });
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(InputWithClearUI, {
      ariaLabel: ariaLabel,
      autoComplete: autoComplete,
      autoFocus: autoFocus,
      button: rightButton,
      disabled: disabled,
      iconClear: !disabled && iconClear,
      id: id,
      reference: refInput,
      inputMode: inputMode,
      isVisibleClear: value,
      leftIcon: leftIcon,
      maxLength: maxLength,
      minLength: minLength,
      onChange: handleChange,
      onClickClear: handleClear,
      onClickRightIcon: handleRightClick,
      onKeyDown: onInputKeyDown,
      placeholder: placeholder,
      required: required,
      rightIcon: rightIcon,
      shape: shape,
      tabIndex: tabIndex,
      type: type,
      value: value,
      children: /*#__PURE__*/_jsx(AtomInput, {})
    }), (value || isOpen) && /*#__PURE__*/_jsx(MoleculeDropdownList, {
      size: size,
      onSelect: handleSelection,
      visible: isOpen && Children.count(children) > 0,
      value: value,
      highlightQuery: value,
      onKeyDown: onKeyDown,
      design: design,
      children: children
    })]
  });
};

MoleculeAutosuggestSingleSelection.displayName = 'MoleculeAutosuggestSingleSelection';
export default MoleculeAutosuggestSingleSelection;
